==> ejc-procurement-api-3.0.0-20251215.045507-118-sources.jar: com/ejianc/business/procurement/perform/vo/ScoreAnswerVO.java <==
package com.ejianc.business.procurement.perform.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 应答文件评审-评审清单
 * 
 * @author generator
 * 
 */
public class ScoreAnswerVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private BigDecimal score; // 分值
    private Integer type; // 类型
    private Long pid; // 主表主键
    private Integer sequence; // 排序
    private String name; // 评价项目
    private String code; // 编码
    private Long parentId; // 父ID
    

    public BigDecimal getScore() {
        return score;
    }

    public void setScore(BigDecimal score) {
        this.score = score;
    }
    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }
    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    public Integer getSequence() {
        return sequence;
    }

    public void setSequence(Integer sequence) {
        this.sequence = sequence;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }
    
}

==> ejc-procurement-api-3.0.0-20251215.092925-128-sources.jar: com/ejianc/business/procurement/perform/vo/ScoreAnswerVO.java <==
package com.ejianc.business.procurement.perform.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 应答文件评审-评审清单
 * 
 * @author generator
 * 
 */
public class ScoreAnswerVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private BigDecimal score; // 分值
    private Integer type; // 类型
    private Long pid; // 主表主键
    private Integer sequence; // 排序
    private String name; // 评价项目
    private String code; // 编码
    private Long parentId; // 父ID
    private String tid;
    private String tpid;


    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }
    

    public BigDecimal getScore() {
        return score;
    }

    public void setScore(BigDecimal score) {
        this.score = score;
    }
    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }
    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    public Integer getSequence() {
        return sequence;
    }

    public void setSequence(Integer sequence) {
        this.sequence = sequence;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }
    
}
